@@ -3,11 +3,11 @@ Manage virtual machines
 """
 
 import os
-from buildkit import facilify
+from buildkit import stacks
 
 arg_specs = []
-child_command_specs = facilify.find_commands(__package__, os.path.dirname(__file__))
-help_template = facilify.main_help_template + """
+child_command_specs = stacks.find_commands(__package__, os.path.dirname(__file__))
+help_template = stacks.main_help_template + """
 
 You can start a virtual machine using the buildkit-vm-start command. 
 For example:
